pitchtools.PitchSet
===================

.. abjad-lineage:: abjad.tools.pitchtools.PitchSet.PitchSet

.. autoclass:: abjad.tools.pitchtools.PitchSet.PitchSet

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.PitchSet.PitchSet.copy
      ~abjad.tools.pitchtools.PitchSet.PitchSet.custom_identifier
      ~abjad.tools.pitchtools.PitchSet.PitchSet.difference
      ~abjad.tools.pitchtools.PitchSet.PitchSet.duplicate_pitch_classes
      ~abjad.tools.pitchtools.PitchSet.PitchSet.from_selection
      ~abjad.tools.pitchtools.PitchSet.PitchSet.intersection
      ~abjad.tools.pitchtools.PitchSet.PitchSet.invert
      ~abjad.tools.pitchtools.PitchSet.PitchSet.is_equivalent_under_transposition
      ~abjad.tools.pitchtools.PitchSet.PitchSet.is_pitch_class_unique
      ~abjad.tools.pitchtools.PitchSet.PitchSet.isdisjoint
      ~abjad.tools.pitchtools.PitchSet.PitchSet.issubset
      ~abjad.tools.pitchtools.PitchSet.PitchSet.issuperset
      ~abjad.tools.pitchtools.PitchSet.PitchSet.item_class
      ~abjad.tools.pitchtools.PitchSet.PitchSet.symmetric_difference
      ~abjad.tools.pitchtools.PitchSet.PitchSet.transpose
      ~abjad.tools.pitchtools.PitchSet.PitchSet.union
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__and__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__contains__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__eq__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__format__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__ge__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__gt__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__hash__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__iter__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__le__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__len__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__lt__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__makenew__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__ne__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__or__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__repr__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__str__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__sub__
      ~abjad.tools.pitchtools.PitchSet.PitchSet.__xor__

Bases
-----

- :py:class:`pitchtools.Set <abjad.tools.pitchtools.Set.Set>`

- :py:class:`datastructuretools.TypedFrozenset <abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchSet.PitchSet.duplicate_pitch_classes
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchSet.PitchSet.is_pitch_class_unique
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchSet.PitchSet.item_class
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.PitchSet.PitchSet.custom_identifier
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.intersection
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.invert
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.is_equivalent_under_transposition
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.isdisjoint
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.issubset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.issuperset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.transpose
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.union
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__makenew__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__sub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchSet.PitchSet.__xor__
   :noindex:
